package com.ruoyi.system.mapper;

import java.util.Date;
import java.util.List;

import com.ruoyi.system.domain.PoCollection;
import com.ruoyi.system.domain.PoTether;
import org.apache.ibatis.annotations.Param;

/**
 * 套系Mapper接口
 *
 * @author ruoyi
 * @date 2023-02-12
 */
public interface PoTetherMapper
{
    /**
     * 查询套系
     *
     * @param tetherId 套系主键
     * @return 套系
     */
    public PoTether selectPoTetherByTetherId(Long tetherId);

    /**
     * 查询套系列表
     *
     * @param poTether 套系
     * @return 套系集合
     */
    public List<PoTether> selectPoTetherSellingList(PoTether poTether);

    /**
     * 新增套系
     *
     * @param poTether 套系
     * @return 结果
     */
    public int insertPoTether(PoTether poTether);

    /**
     * 修改套系
     *
     * @param poTether 套系
     * @return 结果
     */
    public int updatePoTether(PoTether poTether);

    /**
     * 删除套系
     *
     * @param tetherId 套系主键
     * @return 结果
     */
    public int deletePoTetherByTetherId(Long tetherId);

    /**
     * 批量删除套系
     *
     * @param tetherIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePoTetherByTetherIds(Long[] tetherIds);

    /**
     * 按照标题和时间搜索
     * @param title
     * @param tetherTimeStart
     * @param tetherTimeEnd
     * @return
     */
    List<PoTether> selectPoTetherListByTitleAndTetherTimeStartAndTetherTimeEnd(@Param("tetherName") String title,
                                                                               @Param("tetherTimeStart") Date tetherTimeStart,
                                                                               @Param("tetherTimeEnd") Date tetherTimeEnd);

    /**
     * 预售
     * @param poTether
     * @return
     */
    List<PoTether> selectPoTetherAdvanceList(PoTether poTether);

    /**
     * 已过期
     * @param poTether
     * @return
     */
    List<PoTether> selectPoTetherSelledList(PoTether poTether);

    /**
     * 在售
     * @param poTether
     * @return
     */
    List<PoTether> selectPoTetherList(PoTether poTether);


    /**
     * 通过id查询藏品详细信息
     * @param tetherId
     * @return
     */
    List<PoCollection> selectPoCollectionListById(Long tetherId);

    /**
     * 检验标题是否重复
     * @param tetherId
     * @return
     */
    PoTether checkPostTetherTitleUnique(Long tetherId);

    /**
     * 检验图片是否重复
     * @param image
     * @return
     */
    PoTether checkPostTetherImageUnique(String image);

    void removePoTetherByTetherIdsWithCollection(Long[] tetherIds);
}
